import matplotlib.pyplot as plt

def plot_binary(
  df,
  cols = ['x1', 'x2', 'y'],
  markers = ['s','o'],
  fills = ['#ddf', '#fdd'],
  strokes = ['b', 'r'],
  labels = [0, 1],
):
    x1 = df[cols[0]].tolist() 
    x2 = df[cols[1]].tolist()
    y = df[cols[2]].tolist()
    
    plt.figure(figsize=(4, 4))
    for i in range(len(y)):
        m = markers[labels.index(y[i])]
        mec = strokes[labels.index(y[i])]
        mfc = fills[labels.index(y[i])]
        plt.plot(x1[i], x2[i], marker=m, mec=mec, mfc=mfc)
    
    plt.xlabel(cols[0])
    plt.ylabel(cols[1])
    plt.grid();



# vect2.py
# vect2 module
# Sparisoma Viridi | https://github.com/dudung

# 20220914
#   1838 Change __str__ output to JSON format.
# 20220520
#   0503 copy from vect3.
#   0512 erase some methods.
#   0520 test all methods from vect3 and ok.
#   0528 define __neg__ and test ok.

import math

class Vect2:
  def __init__(self, x=0, y=0):
    self.x = x
    self.y = y
  
  def __str__(self):
    str = '{ '
    str += f'"x": {self.x}' + ', '
    str += f'"y": {self.y}'
    str += ' }'
    return str
  
  def __add__(self, other):
    r = Vect2()
    r.x = self.x + other.x
    r.y = self.y + other.y
    return r
  
  def __sub__(self, other):
    r = Vect2()
    r.x = self.x - other.x
    r.y = self.y - other.y
    return r
  
  def __mul__(self, other):
    r = Vect2()
    if isinstance(other, int) | isinstance(other, float):
      r.x = self.x * other
      r.y = self.y * other
    return r
  
  def __rmul__(self, other):
    r = Vect2()
    if isinstance(other, int) | isinstance(other, float):
      r = self.__mul__(other)
    return r
  
  def __or__(self, other):
    l = 0
    if isinstance(other, Vect2):
      lx = self.x * other.x
      ly = self.y * other.y
      l = lx + ly
    return l
  
  def __truediv__ (self, other):
    r = Vect2()
    if isinstance(other, float) | isinstance(other, int):
      r.x = self.x / other
      r.y = self.y / other
    return r
  
  def len(self):
    l = math.sqrt(self | self);
    return l
  
  def __rshift__(self, other):
    u = Vect2()
    r = self
    l = r.len()
    if l != 0:
      u = r / l
    s = u * other 
    return s

  def copy(self):
    r = Vect2()
    r.x = self.x
    r.y = self.y
    return r
  
  def __neg__(self):
    r = Vect2()
    r.x = -self.x
    r.y = -self.y
    return r


import numpy as np
import pandas as pd

def binary(
  coeffs,
  labels=[0, 1],
  r1=[0, 1.1, 0.1],
  r2=[0, 1.1, 0.1]
):
    x1 = []
    x2 = []
    y = []
    
    for i2 in np.arange(r2[0], r2[1], r2[2]):
        for i1 in np.arange(r1[0], r1[1], r1[2]):
            sum = 0
            for i, ci in enumerate(coeffs):
                p = i
                for j, cj in enumerate(ci):
                   p1 = p - j
                   p2 = j
                   sum += cj * i1**p1 * i2**p2
    
            x1.append(i1)
            x2.append(i2)
            if sum > 0:
               y.append(labels[1])
            else:
               y.append(labels[0])
    
    df = pd.DataFrame({
        'x1': x1,
        'x2': x2,
        'y': y
    })
    
    return df
